#
# spec file for package r8168
#
# Copyright (c) 2019 Packman Team <packman@links2linux.de>
# Copyright (c) 2017 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.links2linux.org/
#

#!BuildIgnore: enough-build-resources
Name:           r8168
Version:        8.048.03
Release:        2.19
Summary:        Device driver for RealTek Gigabit Ethernet controllers
License:        GPL-2.0-or-later
Group:          System/Kernel
URL:            https://github.com/mtorromeo/r8168
Source0:        https://github.com/mtorromeo/r8168/archive/%{version}.tar.gz#/%{name}-%{version}.tar.gz
Source1:        preamble
Source2:        Module.supported
Patch0:         r8168-kernel_version.patch
Patch1:         r8168-configuration.patch
BuildRequires:  kernel-source
BuildRequires:  kernel-syms
BuildRequires:  libelf-devel
BuildRequires:  module-init-tools
Requires:       r8168-kmp
ExclusiveArch:  %{ix86} x86_64
%kernel_module_package -p preamble

%description
This is the Linux device driver released for RealTek RTL8168B/8111B,
RTL8168C/8111C, RTL8168CP/8111CP, RTL8168D/8111D, RTL8168DP/8111DP,
and RTL8168E/8111E Gigabit Ethernet controllers with PCI-Express interface.

%package blacklist-r8169
Summary:        To favour r8168 blacklist the r8169 device driver
Group:          Hardware/Wifi
##BuildArch:      noarch
Requires:       %{name}-kmp = %{version}

%description blacklist-r8169
On many Realtek Ethernet controllers the old device driver r8169 does
not work reliably.  To solve this the r8169 kernel module has to be
blacklisted to enable the system to load the new device driver r8168.

%prep
%setup -q
%patch0 -b .p0
%patch1 -b .p1
cp %{S:1} .
cp %{S:2} .

%build
#
# SUSE kernel does include some patches/commits which do not increase
# the kernel's version, there we test here if the linux/pci-acpi.h exits
#
if test -e /usr/src/linux/include/linux/pci-aspm.h
then
    sed -ri '/#define HAS_PCI_ASPM_H/{ s/@ASPM@/1/ }' src/r8168_n.c
else
    sed -ri '/#define HAS_PCI_ASPM_H/{ s/@ASPM@/0/ }' src/r8168_n.c
fi
ln -sf $(type -p kmod) modinfo
mkdir obj
for flavor in %{flavors_to_build}
do
    rm   -rf obj/$flavor
    cp   -rp src obj/$flavor
    make V=1 -C %{kernel_source $flavor} M=$PWD/obj/$flavor modules
    ./modinfo -F alias $(find $PWD/obj/$flavor/ -name '%{name}.ko')
done

%install
export INSTALL_MOD_PATH=%{buildroot}
export INSTALL_MOD_DIR=updates
for flavor in %{flavors_to_build}
do
    make -C %{kernel_source $flavor} M=$PWD/obj/$flavor modules_install
done
mkdir -p %{buildroot}%{_sysconfdir}/modprobe.d/
cat > %{buildroot}%{_sysconfdir}/modprobe.d/50-blacklist-r8169.conf<<-'EOF'
	# On many Realtek Ethernet controllers the old device driver r8169 does
	# not work reliably.  To solve this the r8169 kernel module has to be
	# blacklisted to enable the system to load the new device driver r8168.
	blacklist r8169
	EOF

%files blacklist-r8169
%config %{_sysconfdir}/modprobe.d/50-blacklist-r8169.conf

%changelog
* Thu Jan 21 2021 Werner Fink <werner@suse.de>
- Now we change to github for basic download
- Configure exisxtence of linux/pci-aspm.h on the fly
* Tue Jun  2 2020 Luigi Baldoni <aloisio@gmx.com>
- Update to version 8.048.03
- Drop 83b957b4.patch (fixed upstream)
* Tue Mar 31 2020 Werner Fink <werner@suse.de>
- Add patch 83b957b4.patch to get it build for kernel 5.6
* Mon Feb 10 2020 Werner Fink <werner@suse.de>
- Update to new version 8.048.00
- Modify patch r8168-kernel_version.patch as upstream now supports 5.4
* Tue Nov 26 2019 Werner Fink <werner@suse.de>
- Update to new version 8.047.05
- Modify patch r8168-kernel_version.patch to let it build with 5.4
* Thu Oct 24 2019 Werner Fink <werner@suse.de>
- (Re)add #!BuildIgnore: enough-build-resources
* Tue Oct 22 2019 Werner Fink <werner@suse.de>
- Update to new version 8.047.04
* Wed Jun  5 2019 Luigi Baldoni <aloisio@gmx.com>
- Spec cleanup
* Fri May 24 2019 Werner Fink <werner@suse.de>
- Update to new version 8.047.01
- Remove patch r8168-kernel-4.15-2.patch as now upstream
- Modify patch kernel_version.patch
* Sun Feb  4 2018 werner.fink@opensuse.org
- Add patch r8168-kernel-4.15-2.patch to be prepared for kernel
  4.15+, dropped setup_timer
* Wed Jan 10 2018 werner.fink@opensuse.org
- Update to version r8168-8.045.08
* Thu Aug 10 2017 werner@suse.de
- Rework build of module, that is use obj directory
* Thu Aug  3 2017 werner@suse.de
- Initial package for missing kernel device driver r8168 8.044.02
